diff --git a/README.md b/README.md
index c725cefa..af85c130 100644
--- a/README.md
+++ b/README.md
@@ -1,8 +1,8 @@
-
+
**[Puma](https://avataresargentinos.com.ar) is a free client for 3D virtual worlds such as Second Life and various OpenSim worlds where users can create, connect and chat with others from around the world.**
-This repository contains the official source code for the Firestorm viewer.
+This repository contains the official source code for the Puma viewer.
## Open Source
@@ -10,7 +10,7 @@ Puma is a third party viewer derived from the official [Second Life](https://git
## Download
-Pre-built versions of the viewer releases for Windows, Mac and Linux can be downloaded from the [official website](https://avataresargentinos.com.ar/descargas/).
+Pre-built versions of the viewer releases for Windows and Linux can be downloaded from the [official website](https://wiki.avataresargentinos.com.ar/descargas/).
## Build Instructions
@@ -22,3 +22,4 @@ Build instructions for each operating system can be found using the links below
## Contribute
+Help make Firestorm better! You can get involved with improvements by filing bugs and suggesting enhancements via [JIRA](https://git.avataresargentinos.com.ar/Damian/Puma_Viewer/issues).
diff --git a/autobuild.xml b/autobuild.xml
index 21ae87a4..9cbb4598 100644
--- a/autobuild.xml
+++ b/autobuild.xml
@@ -3276,7 +3276,7 @@ Copyright (c) 2012, 2014, 2015, 2016 nghttp2 contributors
-DCMAKE_BUILD_TYPE:STRING=Release
-DADDRESS_SIZE:STRING=$AUTOBUILD_ADDRSIZE
-DROOT_PROJECT_NAME:STRING=SecondLife
- -DINSTALL_PROPRIETARY=TRUE
+ -DINSTALL_PROPRIETARY=FALSE
-DCMAKE_JOB_POOLS:STRING=compile=4;link=2
diff --git a/doc/puma_256.png b/doc/puma_256.png
new file mode 100644
index 00000000..cef47529
Binary files /dev/null and b/doc/puma_256.png differ
diff --git a/indra/CMakeLists.txt b/indra/CMakeLists.txt
index c59a9db3..cb197c4d 100644
--- a/indra/CMakeLists.txt
+++ b/indra/CMakeLists.txt
@@ -107,7 +107,6 @@ add_subdirectory(${LIBS_OPEN_PREFIX}llcharacter)
add_subdirectory(${LIBS_OPEN_PREFIX}llcommon)
add_subdirectory(${LIBS_OPEN_PREFIX}llcorehttp)
add_subdirectory(${LIBS_OPEN_PREFIX}llimage)
-add_subdirectory(${LIBS_OPEN_PREFIX}llkdu)
add_subdirectory(${LIBS_OPEN_PREFIX}llimagej2coj)
add_subdirectory(${LIBS_OPEN_PREFIX}llinventory)
add_subdirectory(${LIBS_OPEN_PREFIX}llmath)
diff --git a/indra/llcommon/indra_constants.h b/indra/llcommon/indra_constants.h
index 98eb7640..0899fb63 100644
--- a/indra/llcommon/indra_constants.h
+++ b/indra/llcommon/indra_constants.h
@@ -32,7 +32,7 @@
class LLUUID;
// Centralize definition of application name
-const std::string APP_NAME = "Puma";
+const std::string APP_NAME = "Firestorm";
static const F32 REGION_WIDTH_METERS = 256.f;
static const S32 REGION_WIDTH_UNITS = 256;
diff --git a/indra/llfilesystem/lldir.cpp b/indra/llfilesystem/lldir.cpp
index 38dab42d..ad9f5c4d 100644
--- a/indra/llfilesystem/lldir.cpp
+++ b/indra/llfilesystem/lldir.cpp
@@ -541,10 +541,10 @@ std::string LLDir::getExpandedFilename(ELLPath location, const std::string& subd
prefix = add(getAppRODataDir(), "character");
break;
- case LL_PATH_FS_RESOURCES:
+ case LL_PATH_PM_RESOURCES:
prefix = getAppRODataDir();
prefix += mDirDelimiter;
- prefix += "fs_resources";
+ prefix += "pm_resources";
break;
case LL_PATH_HELP:
diff --git a/indra/llfilesystem/lldir.h b/indra/llfilesystem/lldir.h
index 5c869260..e46fc332 100644
--- a/indra/llfilesystem/lldir.h
+++ b/indra/llfilesystem/lldir.h
@@ -53,7 +53,7 @@ typedef enum ELLPath
LL_PATH_TOP_SKINTHEME = 20,
// [/SL:KB]
// Firestorm data
- LL_PATH_FS_RESOURCES = 21,
+ LL_PATH_PM_RESOURCES = 21,
//
// Sound cache
LL_PATH_FS_SOUND_CACHE = 22,
diff --git a/indra/llwindow/llwindowsdl.cpp b/indra/llwindow/llwindowsdl.cpp
index ae92f993..e062bba3 100644
--- a/indra/llwindow/llwindowsdl.cpp
+++ b/indra/llwindow/llwindowsdl.cpp
@@ -726,7 +726,7 @@ bool LLWindowSDL::createContext(int x, int y, int width, int height, int bits, b
// Set the application icon.
SDL_Surface *bmpsurface;
- bmpsurface = Load_BMP_Resource("firestorm_icon.BMP");
+ bmpsurface = Load_BMP_Resource("puma_icon.BMP");
if (bmpsurface)
{
// This attempts to give a black-keyed mask to the icon.
diff --git a/indra/llwindow/llwindowsdl2.cpp b/indra/llwindow/llwindowsdl2.cpp
index 5c34e99a..f17f3376 100644
--- a/indra/llwindow/llwindowsdl2.cpp
+++ b/indra/llwindow/llwindowsdl2.cpp
@@ -814,7 +814,7 @@ bool LLWindowSDL::createContext(int x, int y, int width, int height, int bits, b
// Set the application icon.
SDL_Surface *bmpsurface;
- bmpsurface = Load_BMP_Resource("firestorm_icon.BMP");
+ bmpsurface = Load_BMP_Resource("puma_icon.BMP");
if (bmpsurface)
{
SDL_SetWindowIcon(mWindow, bmpsurface);
diff --git a/indra/newview/CMakeLists.txt b/indra/newview/CMakeLists.txt
index b5575066..c4446a8d 100644
--- a/indra/newview/CMakeLists.txt
+++ b/indra/newview/CMakeLists.txt
@@ -26,7 +26,6 @@ include(LLCA)
include(LLCommon)
include(LLCoreHttp)
include(LLImage)
-include(LLKDU)
include(LLPhysicsExtensions)
include(LLPrimitive)
include(LLWindow)
@@ -1740,11 +1739,11 @@ LIST(APPEND viewer_SOURCE_FILES fsfloaterdiscord.cpp fsdiscordconnect.cpp)
# Generate the version information header file.
configure_file(
- ${CMAKE_CURRENT_SOURCE_DIR}/pmversionvalues.h.in
- ${CMAKE_CURRENT_BINARY_DIR}/pmversionvalues.h
+ ${CMAKE_CURRENT_SOURCE_DIR}/fsversionvalues.h.in
+ ${CMAKE_CURRENT_BINARY_DIR}/fsversionvalues.h
@ONLY
)
-list(APPEND viewer_HEADER_FILES ${CMAKE_CURRENT_BINARY_DIR}/pmversionvalues.h)
+list(APPEND viewer_HEADER_FILES ${CMAKE_CURRENT_BINARY_DIR}/fsversionvalues.h)
#
source_group("CMake Rules" FILES ViewerInstall.cmake)
@@ -2147,11 +2146,11 @@ set_source_files_properties(${viewer_FONT_FILES}
PROPERTIES HEADER_FILE_ONLY TRUE)
list(APPEND viewer_SOURCE_FILES ${viewer_FONT_FILES})
-file(GLOB viewer_FS_RESOURCES pm_resources/*)
-source_group("puma Resources" FILES ${viewer_FS_RESOURCES})
-set_source_files_properties(${viewer_FS_RESOURCES}
+file(GLOB viewer_PM_RESOURCES pm_resources/*)
+source_group("Puma Resources" FILES ${viewer_PM_RESOURCES})
+set_source_files_properties(${viewer_PM_RESOURCES}
PROPERTIES HEADER_FILE_ONLY TRUE)
-list(APPEND viewer_SOURCE_FILES ${viewer_FS_RESOURCES})
+list(APPEND viewer_SOURCE_FILES ${viewer_PM_RESOURCES})
file(GLOB viewer_PY_SCRIPTS *.py)
source_group("Python Scripts" FILES ${viewer_PY_SCRIPTS})
@@ -2578,7 +2577,7 @@ set(ARTWORK_DIR ${CMAKE_CURRENT_SOURCE_DIR} CACHE PATH
#
if (LINUX)
- set(product puma-${ARCH}-${VIEWER_SHORT_VERSION}.${VIEWER_VERSION_REVISION})
+ set(product Puma-${ARCH}-${VIEWER_SHORT_VERSION}.${VIEWER_VERSION_REVISION})
# These are the generated targets that are copied to package/
set(COPY_INPUT_DEPENDENCIES
@@ -2868,7 +2867,7 @@ if (PACKAGE AND (RELEASE_CRASH_REPORTING OR NON_RELEASE_CRASH_REPORTING) AND VIE
endif (LINUX)
endif (USE_BUGSPLAT)
- if (DARWIN) #Linux/Windows generates symbols via viewer_manifest.py/fs_viewer_manifest.py
+ if (DARWIN) #Linux/Windows generates symbols via viewer_manifest.py/pm_viewer_manifest.py
# for both Bugsplat and Breakpad
add_dependencies(llpackage generate_symbols)
endif()
diff --git a/indra/newview/Info-Puma.plist b/indra/newview/Info-Puma.plist
new file mode 100644
index 00000000..6b2e73a5
--- /dev/null
+++ b/indra/newview/Info-Puma.plist
@@ -0,0 +1,90 @@
+
+
+
+
+ CFBundleDevelopmentRegion
+ English
+ CFBundleExecutable
+ ${MACOSX_EXECUTABLE_NAME}
+ CFBundleGetInfoString
+ ${MACOSX_BUNDLE_INFO_STRING}
+ CFBundleIconFile
+ ${MACOSX_BUNDLE_ICON_FILE}
+ CFBundleIdentifier
+ ${PRODUCT_BUNDLE_IDENTIFIER}
+ CFBundleInfoDictionaryVersion
+ 6.0
+ CFBundleLongVersionString
+ ${MACOSX_BUNDLE_LONG_VERSION_STRING}
+ CFBundleName
+ ${MACOSX_BUNDLE_BUNDLE_NAME}
+ CFBundlePackageType
+ APPL
+ CFBundleShortVersionString
+ ${MACOSX_BUNDLE_SHORT_VERSION_STRING}
+ CFBundleSignature
+ ????
+ CFBundleVersion
+ ${VIEWER_VERSION_MAJOR}.${VIEWER_VERSION_MINOR}.${VIEWER_VERSION_PATCH}.${VIEWER_VERSION_REVISION}
+ CSResourcesFileMapped
+
+ LSApplicationCategoryType
+ public.app-category.games
+ LSRequiresCarbon
+
+ NSAppSleepDisabled
+
+ NSMicrophoneUsageDescription
+ Microphone access is needed to allow connection to voice.
+ NSHumanReadableCopyright
+ ${MACOSX_BUNDLE_COPYRIGHT}
+ CFBundleDocumentTypes
+
+
+ CFBundleTypeExtensions
+
+ slurl
+
+ CFBundleTypeIconFile
+ seconlife
+ CFBundleTypeMIMETypes
+
+ application/x-grid-location-info
+
+ CFBundleTypeName
+ Secondlife SLURL
+ CFBundleTypeOSTypes
+
+ SLRL
+
+ CFBundleTypeRole
+ Viewer
+ LSTypeIsPackage
+
+ NSDocumentClass
+ SecondLifeSLURL
+
+
+ CFBundleURLTypes
+
+
+ CFBundleURLName
+ Second Life URL
+ CFBundleURLSchemes
+
+ secondlife
+ x-grid-location-info
+ hop
+
+ LSIsAppleDefaultForScheme
+
+
+
+ NSPrincipalClass
+ ${MACOSX_BUNDLE_NSPRINCIPAL_CLASS}
+ NSMainNibFile
+ ${MACOSX_BUNDLE_NSMAIN_NIB_FILE}
+ NSHighResolutionCapable
+
+
+
diff --git a/indra/newview/app_settings/settings_puma.xml b/indra/newview/app_settings/settings_puma.xml
index ea82b96a..1e5602ba 100644
--- a/indra/newview/app_settings/settings_puma.xml
+++ b/indra/newview/app_settings/settings_puma.xml
@@ -80,7 +80,7 @@
Type
String
Value
- puma
+ pumam
SkinCurrentTheme
diff --git a/indra/newview/firestorm_icon.icns b/indra/newview/firestorm_icon.icns
new file mode 100644
index 00000000..a39d58ea
Binary files /dev/null and b/indra/newview/firestorm_icon.icns differ
diff --git a/indra/newview/firestormos_icon.icns b/indra/newview/firestormos_icon.icns
new file mode 100644
index 00000000..3315b964
Binary files /dev/null and b/indra/newview/firestormos_icon.icns differ
diff --git a/indra/newview/fslslbridge.cpp b/indra/newview/fslslbridge.cpp
index c2762351..b509b7eb 100644
--- a/indra/newview/fslslbridge.cpp
+++ b/indra/newview/fslslbridge.cpp
@@ -1350,7 +1350,7 @@ void FSLSLBridgeScriptCallback::fire(const LLUUID& inv_item)
std::string FSLSLBridgeScriptCallback::prepUploadFile(std::string &aBuffer)
{
- const std::string fName = gDirUtilp->getExpandedFilename(LL_PATH_FS_RESOURCES, UPLOAD_SCRIPT_CURRENT);
+ const std::string fName = gDirUtilp->getExpandedFilename(LL_PATH_PM_RESOURCES, UPLOAD_SCRIPT_CURRENT);
const std::string fNew = gDirUtilp->getExpandedFilename(LL_PATH_CACHE,UPLOAD_SCRIPT_CURRENT);
LLFILE* fpIn = LLFile::fopen(fName, "rt");
diff --git a/indra/newview/fsversionvalues.h.in b/indra/newview/fsversionvalues.h.in
new file mode 100755
index 00000000..359c3491
--- /dev/null
+++ b/indra/newview/fsversionvalues.h.in
@@ -0,0 +1,50 @@
+/**
+ * @file fsversionvalues.h.in
+ * @brief Routines to access the viewer version and build information
+ * @author Tonya Souther
+ *
+ * $LicenseInfo:firstyear=2013&license=fsviewerlgpl$
+ * Phoenix Firestorm Viewer Source Code
+ * Copyright (C) 2013, The Phoenix Firestorm Project, Inc.
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation;
+ * version 2.1 of the License only.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ *
+ * The Phoenix Firestorm Project, Inc., 1831 Oakwood Drive, Fairmont, Minnesota 56031-3225 USA
+ * http://www.phoenixviewer.com
+ * $/LicenseInfo$
+ */
+
+#ifndef FS_FSVERSIONVALUES_H
+#define FS_FSVERSIONVALUES_H
+
+// Define the version and channel substitution macros here instead
+// of via cmake compile-time defines in order to not force a rebuild
+// of the entire newview directory with every Mercurial pull
+// NOTE: This file should not be included anywhere in the main viewer code
+// but llversioninfo.cpp. If you need the current viewer version in
+// a different format than is already provided there, then add a
+// function to that file and reference it, rather than building your
+// own function elsewhere.
+#define LL_VIEWER_CHANNEL "@VIEWER_CHANNEL@"
+#define LL_VIEWER_VERSION_MAJOR @VIEWER_VERSION_MAJOR@
+#define LL_VIEWER_VERSION_MINOR @VIEWER_VERSION_MINOR@
+#define LL_VIEWER_VERSION_PATCH @VIEWER_VERSION_PATCH@
+#define LL_VIEWER_VERSION_BUILD @VIEWER_VERSION_REVISION@
+const std::string LL_VIEWER_VERSION_GITHASH {@VIEWER_VERSION_GITHASH@};
+#define LLBUILD_CONFIG "@CMAKE_BUILD_TYPE@"
+
+//
+
+#endif
diff --git a/indra/newview/installers/windows/firestorm_icon.BMP b/indra/newview/installers/windows/firestorm_icon.BMP
new file mode 100644
index 00000000..5b801c63
Binary files /dev/null and b/indra/newview/installers/windows/firestorm_icon.BMP differ
diff --git a/indra/newview/installers/windows/firestorm_icon.ico b/indra/newview/installers/windows/firestorm_icon.ico
new file mode 100644
index 00000000..b557306b
Binary files /dev/null and b/indra/newview/installers/windows/firestorm_icon.ico differ
diff --git a/indra/newview/installers/windows/firestorm_icon_os.ico b/indra/newview/installers/windows/firestorm_icon_os.ico
new file mode 100644
index 00000000..52ddcf37
Binary files /dev/null and b/indra/newview/installers/windows/firestorm_icon_os.ico differ
diff --git a/indra/newview/installers/windows/firestorm_icon_small.BMP b/indra/newview/installers/windows/firestorm_icon_small.BMP
new file mode 100644
index 00000000..f4454a42
Binary files /dev/null and b/indra/newview/installers/windows/firestorm_icon_small.BMP differ
diff --git a/indra/newview/installers/windows/installer_template.nsi b/indra/newview/installers/windows/installer_template.nsi
index 10bcbfe2..0cf7c07d 100644
--- a/indra/newview/installers/windows/installer_template.nsi
+++ b/indra/newview/installers/windows/installer_template.nsi
@@ -87,10 +87,10 @@ Name ${INSTNAME}
;SubCaption 0 $(LicenseSubTitleSetup) # Override "license agreement" text
# FIRE-24335: Use different icon for OpenSim version
-#!define MUI_ICON "%%SOURCE%%\installers\windows\puma_icon_os.ico"
-#!define MUI_UNICON "%%SOURCE%%\installers\windows\puma_icon_os.ico"
-!define MUI_ICON "%%SOURCE%%\installers\windows\puma_icon${ICON_SUFFIX}.ico"
-!define MUI_UNICON "%%SOURCE%%\installers\windows\puma_icon${ICON_SUFFIX}.ico"
+#!define MUI_ICON "%%SOURCE%%\installers\windows\firestorm_icon_os.ico"
+#!define MUI_UNICON "%%SOURCE%%\installers\windows\firestorm_icon_os.ico"
+!define MUI_ICON "%%SOURCE%%\installers\windows\firestorm_icon${ICON_SUFFIX}.ico"
+!define MUI_UNICON "%%SOURCE%%\installers\windows\firestorm_icon${ICON_SUFFIX}.ico"
#
BrandingText " " # Bottom of window text
@@ -105,7 +105,7 @@ SetOverwrite on # Overwrite files by default
#AutoCloseWindow true # After all files install, close window
# Registry key paths, ours and Microsoft's
-!define LINDEN_KEY "SOFTWARE\Avatares Argentinos"
+!define LINDEN_KEY "SOFTWARE\The Phoenix Firestorm Project"
!define INSTNAME_KEY "${LINDEN_KEY}\${INSTNAME}"
!define MSCURRVER_KEY "SOFTWARE\Microsoft\Windows\CurrentVersion"
!define MSNTCURRVER_KEY "SOFTWARE\Microsoft\Windows NT\CurrentVersion"
@@ -538,7 +538,7 @@ CreateShortCut "$SMPROGRAMS\$INSTSHORTCUT\$INSTSHORTCUT.lnk" \
WriteINIStr "$SMPROGRAMS\$INSTSHORTCUT\SL Create Account.url" \
"InternetShortcut" "URL" \
- "https://www.ayudavirtual.org/unirseasl/"
+ "https://www.firestormviewer.org/join-secondlife/"
WriteINIStr "$SMPROGRAMS\$INSTSHORTCUT\SL Your Account.url" \
"InternetShortcut" "URL" \
"https://www.secondlife.com/account/"
@@ -580,10 +580,10 @@ WriteRegStr SHELL_CONTEXT "${INSTNAME_KEY}" "" "$INSTDIR"
WriteRegStr SHELL_CONTEXT "${INSTNAME_KEY}" "Version" "${VERSION_LONG}"
WriteRegStr SHELL_CONTEXT "${INSTNAME_KEY}" "Shortcut" "$INSTSHORTCUT"
WriteRegStr SHELL_CONTEXT "${INSTNAME_KEY}" "Exe" "$VIEWER_EXE"
-WriteRegStr SHELL_CONTEXT "${MSUNINSTALL_KEY}" "Publisher" "Avatares Argentinos"
-WriteRegStr SHELL_CONTEXT "${MSUNINSTALL_KEY}" "URLInfoAbout" "https://avataresargentinos.com.ar"
-WriteRegStr SHELL_CONTEXT "${MSUNINSTALL_KEY}" "URLUpdateInfo" "https://avataresargentinos.com.ar/descargas"
-WriteRegStr SHELL_CONTEXT "${MSUNINSTALL_KEY}" "HelpLink" "https://avataresargentinos.com.ar/soporte"
+WriteRegStr SHELL_CONTEXT "${MSUNINSTALL_KEY}" "Publisher" "The Phoenix Firestorm Project, Inc."
+WriteRegStr SHELL_CONTEXT "${MSUNINSTALL_KEY}" "URLInfoAbout" "https://www.firestormviewer.org"
+WriteRegStr SHELL_CONTEXT "${MSUNINSTALL_KEY}" "URLUpdateInfo" "https://www.firestormviewer.org/downloads"
+WriteRegStr SHELL_CONTEXT "${MSUNINSTALL_KEY}" "HelpLink" "https://www.firestormviewer.org/support"
WriteRegStr SHELL_CONTEXT "${MSUNINSTALL_KEY}" "DisplayName" "$INSTNAME"
WriteRegStr SHELL_CONTEXT "${MSUNINSTALL_KEY}" "UninstallString" '"$INSTDIR\uninst.exe"'
WriteRegStr SHELL_CONTEXT "${MSUNINSTALL_KEY}" "DisplayVersion" "${VERSION_LONG}"
@@ -914,28 +914,28 @@ Push $2
# Required since ProfileImagePath is of type REG_EXPAND_SZ
ExpandEnvStrings $2 $2
-# Delete files in \Users\\AppData\Roaming\Puma
+# Delete files in \Users\\AppData\Roaming\Firestorm
# Remove all settings files but leave any other .txt files to preserve the chat logs
- RMDir /r "$2\AppData\Roaming\Puma\logs"
- RMDir /r "$2\AppData\Roaming\Puma\browser_profile"
- RMDir /r "$2\AppData\Roaming\Puma\user_settings"
- Delete "$2\AppData\Roaming\Puma\*.xml"
- Delete "$2\AppData\Roaming\Puma\*.bmp"
- Delete "$2\AppData\Roaming\Puma\search_history.txt"
- Delete "$2\AppData\Roaming\Puma\plugin_cookies.txt"
- Delete "$2\AppData\Roaming\Puma\typed_locations.txt"
-# Delete files in \Users\\AppData\Local\Puma
+ RMDir /r "$2\AppData\Roaming\Firestorm\logs"
+ RMDir /r "$2\AppData\Roaming\Firestorm\browser_profile"
+ RMDir /r "$2\AppData\Roaming\Firestorm\user_settings"
+ Delete "$2\AppData\Roaming\Firestorm\*.xml"
+ Delete "$2\AppData\Roaming\Firestorm\*.bmp"
+ Delete "$2\AppData\Roaming\Firestorm\search_history.txt"
+ Delete "$2\AppData\Roaming\Firestorm\plugin_cookies.txt"
+ Delete "$2\AppData\Roaming\Firestorm\typed_locations.txt"
+# Delete files in \Users\\AppData\Local\Firestorm
${If} ${ISOPENSIM} == "0"
${If} ${IS64BIT} == "0"
- RMDir /r "$2\AppData\Local\Puma" #Delete the Havok cache folder
+ RMDir /r "$2\AppData\Local\Firestorm" #Delete the Havok cache folder
${Else}
- RMDir /r "$2\AppData\Local\Puma_x64" #Delete the OpenSim cache folder
+ RMDir /r "$2\AppData\Local\Firestorm_x64" #Delete the OpenSim cache folder
${EndIf}
${Else}
${If} ${IS64BIT} == "0"
- RMDir /r "$2\AppData\Local\PumaOS" #Delete the Havok cache folder
+ RMDir /r "$2\AppData\Local\FirestormOS" #Delete the Havok cache folder
${Else}
- RMDir /r "$2\AppData\Local\PumaOS_x64" #Delete the OpenSim cache folder
+ RMDir /r "$2\AppData\Local\FirestormOS_x64" #Delete the OpenSim cache folder
${EndIf}
${EndIf}
@@ -948,11 +948,11 @@ Pop $2
Pop $1
Pop $0
-# Delete files in ProgramData\Puma
+# Delete files in ProgramData\Firestorm
Push $0
ReadRegStr $0 SHELL_CONTEXT "${MSCURRVER_KEY}\Explorer\Shell Folders" "Common AppData"
StrCmp $0 "" +2
- RMDir /r "$0\Puma"
+ RMDir /r "$0\Firestorm"
Pop $0
Keep:
diff --git a/indra/newview/installers/windows/puma_icon.BMP b/indra/newview/installers/windows/puma_icon.BMP
index 858e1137..4bca35fc 100644
Binary files a/indra/newview/installers/windows/puma_icon.BMP and b/indra/newview/installers/windows/puma_icon.BMP differ
diff --git a/indra/newview/installers/windows/puma_icon.ico b/indra/newview/installers/windows/puma_icon.ico
index f2536d22..f1a3ca6a 100644
Binary files a/indra/newview/installers/windows/puma_icon.ico and b/indra/newview/installers/windows/puma_icon.ico differ
diff --git a/indra/newview/linux_tools/PUMA_DESKTOPINSTALL.txt b/indra/newview/linux_tools/PUMA_DESKTOPINSTALL.txt
index f80adc28..55916461 100644
--- a/indra/newview/linux_tools/PUMA_DESKTOPINSTALL.txt
+++ b/indra/newview/linux_tools/PUMA_DESKTOPINSTALL.txt
@@ -1,3 +1,3 @@
-If you wish to install Firestorm on your desktop menus, we no longer do this by default. Instead, run:
+If you wish to install Puma on your desktop menus, we no longer do this by default. Instead, run:
./etc/refresh_desktop_app_entry.sh
diff --git a/indra/newview/linux_tools/handle_secondlifeprotocol.sh b/indra/newview/linux_tools/handle_secondlifeprotocol.sh
index a331b4fa..d0792d3d 100755
--- a/indra/newview/linux_tools/handle_secondlifeprotocol.sh
+++ b/indra/newview/linux_tools/handle_secondlifeprotocol.sh
@@ -16,7 +16,7 @@ RUN_PATH=`dirname "$0" || echo .`
ch "${RUN_PATH}"
#exec ./firestorm -url \'"${URL}"\'
-if [ `pidof do-not-directly-run-puma-bin` ]; then
+if [ `pidof do-not-directly-run-firestorm-bin` ]; then
exec dbus-send --type=method_call --dest=com.secondlife.ViewerAppAPIService /com/secondlife/ViewerAppAPI com.secondlife.ViewerAppAPI.GoSLURL string:"$1"
else
exec ../firestorm -url \'"${URL}"\'
diff --git a/indra/newview/llappviewerlinux.cpp b/indra/newview/llappviewerlinux.cpp
index c52850ad..39af3f99 100644
--- a/indra/newview/llappviewerlinux.cpp
+++ b/indra/newview/llappviewerlinux.cpp
@@ -72,7 +72,7 @@ extern "C"
#endif
#include "boost/json.hpp"
-#include "pmversionvalues.h"
+#include "fsversionvalues.h"
#define VIEWERAPI_SERVICE "com.secondlife.ViewerAppAPIService"
#define VIEWERAPI_PATH "/com/secondlife/ViewerAppAPI"
diff --git a/indra/newview/llmodelpreview.cpp b/indra/newview/llmodelpreview.cpp
index effb9696..27b939b5 100644
--- a/indra/newview/llmodelpreview.cpp
+++ b/indra/newview/llmodelpreview.cpp
@@ -1145,12 +1145,12 @@ void LLModelPreview::setPhysicsFromPreset(S32 preset)
if(preset == 1)
{
mPhysicsSearchLOD = LLModel::LOD_PHYSICS;
- loadModel( gDirUtilp->getExpandedFilename(LL_PATH_FS_RESOURCES, "cube_phys.dae"), LLModel::LOD_PHYSICS);
+ loadModel( gDirUtilp->getExpandedFilename(LL_PATH_PM_RESOURCES, "cube_phys.dae"), LLModel::LOD_PHYSICS);
}
else if(preset == 2)
{
mPhysicsSearchLOD = LLModel::LOD_PHYSICS;
- loadModel( gDirUtilp->getExpandedFilename(LL_PATH_FS_RESOURCES, "hex_phys.dae"), LLModel::LOD_PHYSICS);
+ loadModel( gDirUtilp->getExpandedFilename(LL_PATH_PM_RESOURCES, "hex_phys.dae"), LLModel::LOD_PHYSICS);
}
else if(preset == 3)
{
diff --git a/indra/newview/llversioninfo.cpp b/indra/newview/llversioninfo.cpp
index 8372102b..3614a6b7 100644
--- a/indra/newview/llversioninfo.cpp
+++ b/indra/newview/llversioninfo.cpp
@@ -34,7 +34,7 @@
// Use configured file instead of compile time definitions to avoid
// rebuilding the world with every Mercurial pull
-#include "pmversionvalues.h"
+#include "fsversionvalues.h"
#if ! defined(LL_VIEWER_CHANNEL) \
|| ! defined(LL_VIEWER_VERSION_MAJOR) \
diff --git a/indra/newview/pm_viewer_manifest.py b/indra/newview/pm_viewer_manifest.py
index 93ace869..68046a04 100644
--- a/indra/newview/pm_viewer_manifest.py
+++ b/indra/newview/pm_viewer_manifest.py
@@ -2,9 +2,9 @@ import os
import subprocess
import tarfile
-class FSViewerManifest:
- def fs_installer_basename(self):
- if self.fs_is_avx2():
+class PMViewerManifest:
+ def pm_installer_basename(self):
+ if self.pm_is_avx2():
opt_string = "AVX2"
else:
opt_string = "LEGACY"
@@ -17,14 +17,14 @@ class FSViewerManifest:
'app_name_oneword':self.app_name_oneword()
}
- return "Phoenix-%(app_name)s_%(optimized)s-%(version_dashes)s" % substitution_strings
+ return "Puma-%(app_name)s_%(optimized)s-%(version_dashes)s" % substitution_strings
- def fs_is_opensim(self):
+ def pm_is_opensim(self):
return self.args['viewer_flavor'] == 'oss' #Havok would be hvk
- def fs_is_avx2(self):
+ def pm_is_avx2(self):
return self.args['avx2'] == 'ON'
- def fs_splice_grid_substitution_strings( self, subst_strings ):
+ def pm_splice_grid_substitution_strings( self, subst_strings ):
ret = subst_strings
if 'grid' in self.args and self.args['grid'] != None:
@@ -36,30 +36,30 @@ class FSViewerManifest:
return ret
- def fs_get_substitution_strings( self ):
+ def pm_get_substitution_strings( self ):
substitution_strings = {
'version' : '.'.join(self.args['version']),
'version_short' : '.'.join(self.args['version'][:-1]),
'version_dashes' : '-'.join(self.args['version']),
'channel':self.channel(),
- 'channel_oneword':self.fs_channel_oneword(),
- 'channel_unique':self.fs_channel_unique(),
- 'subchannel_underscores':'_'.join(self.fs_channel_unique().split()),
+ 'channel_oneword':self.pm_channel_oneword(),
+ 'channel_unique':self.pm_channel_unique(),
+ 'subchannel_underscores':'_'.join(self.pm_channel_unique().split()),
'app_name' : self.app_name()
}
- return self.fs_splice_grid_substitution_strings( substitution_strings )
+ return self.pm_splice_grid_substitution_strings( substitution_strings )
- def fs_channel_legacy_oneword(self):
+ def pm_channel_legacy_oneword(self):
return "".join(self.channel().split())
- def fs_channel_oneword(self):
- return "".join(self.fs_channel_unique().split())
+ def pm_channel_oneword(self):
+ return "".join(self.pm_channel_unique().split())
- def fs_channel_unique(self):
+ def pm_channel_unique(self):
return self.channel().replace("Puma", "").strip()
- def fs_sign_win_binaries(self):
+ def pm_sign_win_binaries(self):
signtool_path = os.getenv('SIGNTOOL_PATH')
codesigning_dlib_path = os.getenv('CODESIGNING_DLIB_PATH')
metadata_file = os.getenv("CODESIGNING_METADATA_PATH")
@@ -89,7 +89,7 @@ class FSViewerManifest:
except Exception as e:
print(f"Couldn't sign binary: {exe_path}. Error: {e}")
- def fs_sign_win_installer(self, substitution_strings):
+ def pm_sign_win_installer(self, substitution_strings):
signtool_path = os.getenv('SIGNTOOL_PATH')
codesigning_dlib_path = os.getenv('CODESIGNING_DLIB_PATH')
metadata_file = os.getenv("CODESIGNING_METADATA_PATH")
@@ -109,7 +109,7 @@ class FSViewerManifest:
except Exception as e:
print(f"Couldn't sign windows installer: {installer_path}. Error: {e}")
- def fs_delete_linux_symbols( self ):
+ def pm_delete_linux_symbols( self ):
debugDir = os.path.join( self.get_dst_prefix(), "bin", ".debug" )
if os.path.exists( debugDir ):
@@ -121,34 +121,34 @@ class FSViewerManifest:
if os.path.isfile( debugFile ):
os.unlink( debugFile )
- def fs_save_linux_symbols( self ):
+ def pm_save_linux_symbols( self ):
#AO: Try to package up symbols
# New Method, for reading cross platform stack traces on a linux/mac host
print("Packaging symbols")
- self.fs_save_symbols("linux")
+ self.pm_save_symbols("linux")
def fs_linux_tar_excludes(self):
- installer_name_components = ['Phoenix',self.app_name(),self.args.get('arch'),'.'.join(self.args['version'])]
+ installer_name_components = ['Puma',self.app_name(),self.args.get('arch'),'.'.join(self.args['version'])]
installer_name = "_".join(installer_name_components)
return "--exclude=%s/bin/.debug" % installer_name
- def fs_save_windows_symbols(self):
- self.fs_save_symbols("windows")
+ def pm_save_windows_symbols(self):
+ self.pm_save_symbols("windows")
pdbName = "puma-bin.pdb"
try:
subprocess.check_call( [ "pdbcopy.exe" ,
- self.args['configuration'] + "\\puma-bin.pdb",
- self.args['configuration'] + "\\puma-bin-public.pdb",
+ self.args['configuration'] + "\\firestorm-bin.pdb",
+ self.args['configuration'] + "\\firestorm-bin-public.pdb",
"-p"
], stderr=subprocess.PIPE,stdout=subprocess.PIPE )
pdbName = "puma-bin-public.pdb"
except:
print("Cannot run pdbcopy, packaging private symbols")
- tarName = "%s/Phoenix_%s_%s_%s_pdbsymbols-windows-%d.tar.xz" % (self.args['configuration'].lower(),
- self.fs_channel_legacy_oneword(),
+ tarName = "%s/Puma_%s_%s_%s_pdbsymbols-windows-%d.tar.xz" % (self.args['configuration'].lower(),
+ self.pm_channel_legacy_oneword(),
'-'.join(self.args['version']),
self.args['viewer_flavor'],
self.address_size)
@@ -159,7 +159,7 @@ class FSViewerManifest:
symbolTar.add( "%s/%s" % (self.args['configuration'].lower(),pdbName), pdbName )
symbolTar.close()
- def fs_strip_windows_manifest(self, aFile ):
+ def pm_strip_windows_manifest(self, aFile ):
try:
from win32api import BeginUpdateResource, UpdateResource, EndUpdateResource
@@ -170,10 +170,10 @@ class FSViewerManifest:
except:
pass
- def fs_copy_windows_manifest(self):
+ def pm_copy_windows_manifest(self):
from shutil import copyfile
- self.fs_strip_windows_manifest( "%s/slplugin.exe" % self.args['configuration'].lower() )
- self.fs_strip_windows_manifest( "%s/llplugin/dullahan_host.exe" % self.args['configuration'].lower() )
+ self.pm_strip_windows_manifest( "%s/slplugin.exe" % self.args['configuration'].lower() )
+ self.pm_strip_windows_manifest( "%s/llplugin/dullahan_host.exe" % self.args['configuration'].lower() )
if self.prefix(src=os.path.join(self.args['build'], os.pardir, os.pardir, 'indra', 'tools', 'manifests')):
self.path( "compatibility.manifest", "slplugin.exe.manifest" )
self.end_prefix()
@@ -181,16 +181,16 @@ class FSViewerManifest:
self.path( "compatibility.manifest", "dullahan_host.exe.manifest" )
self.end_prefix()
- def fs_save_osx_symbols( self ):
- self.fs_save_symbols("darwin")
+ def pm_save_osx_symbols( self ):
+ self.pm_save_symbols("darwin")
- def fs_save_symbols(self, osname):
+ def pm_save_symbols(self, osname):
if (os.path.exists("%s/puma-symbols-%s-%d.tar.bz2" % (self.args['configuration'].lower(),
osname,
self.address_size))):
# Rename to add version numbers
- sName = "%s/Phoenix_%s_%s_%s_symbols-%s-%d.tar.bz2" % (self.args['configuration'].lower(),
- self.fs_channel_legacy_oneword(),
+ sName = "%s/Puma_%s_%s_%s_symbols-%s-%d.tar.bz2" % (self.args['configuration'].lower(),
+ self.pm_channel_legacy_oneword(),
'-'.join( self.args['version'] ),
self.args['viewer_flavor'],
osname,
@@ -201,7 +201,7 @@ class FSViewerManifest:
os.rename("%s/puma-symbols-%s-%d.tar.bz2" % (self.args['configuration'].lower(), osname, self.address_size), sName)
- def fs_generate_breakpad_symbols_for_file( self, aFile ):
+ def pm_generate_breakpad_symbols_for_file( self, aFile ):
from os import makedirs, remove
from os.path import join, isfile
import subprocess
@@ -230,14 +230,14 @@ class FSViewerManifest:
if isfile( symbolFile ):
remove( symbolFile )
- def fs_save_breakpad_symbols(self, osname):
+ def pm_save_breakpad_symbols(self, osname):
from glob import glob
import sys
from os.path import isdir, join
from shutil import rmtree
import tarfile
- components = ['Phoenix',self.app_name(),self.args.get('arch'),'.'.join(self.args['version'])]
+ components = ['Puma',self.app_name(),self.args.get('arch'),'.'.join(self.args['version'])]
symbolsName = "_".join(components)
symbolsName = symbolsName + "_" + self.args["viewer_flavor"] + "-" + osname + "-" + str(self.address_size) + ".tar.bz2"
@@ -246,12 +246,12 @@ class FSViewerManifest:
files = glob( "%s/bin/*" % self.args['dest'] )
for f in files:
- self.fs_generate_breakpad_symbols_for_file( f )
+ self.pm_generate_breakpad_symbols_for_file( f )
files = glob( "%s/lib/*.so" % self.args['dest'] )
for f in files:
if f.find( "libcef.so" ) == -1:
- self.fs_generate_breakpad_symbols_for_file( f )
+ self.pm_generate_breakpad_symbols_for_file( f )
if isdir( "symbols" ):
for a in self.args:
diff --git a/indra/newview/res/puma_icon.png b/indra/newview/res/puma_icon.png
index 48a460ae..14e4e652 100644
Binary files a/indra/newview/res/puma_icon.png and b/indra/newview/res/puma_icon.png differ
diff --git a/indra/newview/skins/default/textures/windows/login_fs_logo.png b/indra/newview/skins/default/textures/windows/login_fs_logo.png
new file mode 100644
index 00000000..c09c8cf0
Binary files /dev/null and b/indra/newview/skins/default/textures/windows/login_fs_logo.png differ
diff --git a/indra/newview/skins/skins.xml b/indra/newview/skins/skins.xml
index ff5be78e..9f42ec3e 100644
--- a/indra/newview/skins/skins.xml
+++ b/indra/newview/skins/skins.xml
@@ -1,20 +1,5 @@
-
name
AnsaStorm
diff --git a/pmutils/build_config.json b/pmutils/build_config.json
index dde1887b..ab14acea 100644
--- a/pmutils/build_config.json
+++ b/pmutils/build_config.json
@@ -28,7 +28,7 @@
"SL": "Second Life",
"OS": "OpenSim"
},
- "download_root": "https://app.avataresargentinos.com.ar/descargas",
+ "download_root": "https://wiki.avataresargentinos.com.ar/descargas",
"viewer_channel_mapping": {
"Release": "release",
"Beta": "beta",
diff --git a/pmutils/build_config.py b/pmutils/build_config.py
index 5b90109c..2d812c81 100644
--- a/pmutils/build_config.py
+++ b/pmutils/build_config.py
@@ -10,7 +10,7 @@ class BuildConfig:
self.supported_os_dirs = config_data.get('os_download_dirs', [])
# channel_to_build_type is a map from Beta, Release and Nightly to folder names preview release and nightly
self.build_type_hosted_folder = config_data.get('build_type_hosted_folder', {})
- self.fs_version_mgr_platform = config_data.get('pm_version_mgr_platform', {})
+ self.fs_version_mgr_platform = config_data.get('fs_version_mgr_platform', {})
self.os_hosted_folder = config_data.get('os_hosted_folder', {})
self.platforms_printable = config_data.get('platforms_printable', {})
self.grids_printable = config_data.get('grids_printable', {})
diff --git a/scripts/configure_puma.sh b/scripts/configure_puma.sh
index 15e145f7..321c1e62 100755
--- a/scripts/configure_puma.sh
+++ b/scripts/configure_puma.sh
@@ -600,7 +600,7 @@ if [ $WANTS_BUILD -eq $TRUE ] ; then
else
JOBS="-jobs $JOBS"
fi
- xcodebuild -configuration $BTYPE -project puma.xcodeproj $JOBS 2>&1 | tee -a "$LOG"
+ xcodebuild -configuration $BTYPE -project Puma.xcodeproj $JOBS 2>&1 | tee -a "$LOG"
elif [ $TARGET_PLATFORM == "linux" ] ; then
if [ $JOBS == "0" ] ; then
JOBS=`cat /proc/cpuinfo | grep processor | wc -l`
diff --git a/indra/newview/linux_tools/install.sh b/indra/newview/linux_tools/install.sh
index 6ccde535..d6e11f93 100755
--- a/indra/newview/linux_tools/install.sh
+++ b/indra/newview/linux_tools/install.sh
@@ -1,6 +1,6 @@
#!/bin/bash
# Enhanced Puma Viewer Installation Script
# Features:
# - Creates a timestamped backup of existing installation
# - Allows installation with custom suffixes for parallel versions (e.g., beta, release, debug)
@@ -179,16 +179,16 @@ parse_arguments() {
}
# Function to download Puma Viewer (optional enhancement)
-download_puma() {
- # Define Puma Viewer download URL
+download_firestorm() {
+ # Define Firestorm Viewer download URL
# NOTE: Replace this URL with the actual download link as needed
- PUMA_URL="https://avataresargentinos/puma/descargas/linux/puma.tar.gz"
+ FIRESTORM_URL="https://wiki.avataresargentinos.com.ar/descargas/linux/puma.tar.gz"
# Temporary download location
TEMP_DOWNLOAD="/tmp/puma.tar.gz"
- echo "Downloading Puma Viewer from $PUMA_URL..."
- wget -O "$TEMP_DOWNLOAD" "$PUMA_URL" || die "Failed to download Puma Viewer!"
+ echo "Downloading Puma Viewer from $FIRESTORM_URL..."
+ wget -O "$TEMP_DOWNLOAD" "$FIRESTORM_URL" || die "Failed to download Puma Viewer!"
echo "Download completed."
# Extract the tarball to the run path
@@ -201,7 +201,7 @@ download_puma() {
# Main installation workflow
main() {
- echo "Starting Puma Viewer installation script..."
+ echo "Starting Pumaw Viewer installation script..."
# Parse command-line arguments
parse_arguments "$@"
@@ -213,7 +213,7 @@ main() {
# Optionally, download Puma Viewer if not already present
# Uncomment the following line if you want the script to handle downloading
- # download_Puma
+ # download_puma
# Determine if the script is run as root
if [[ "$EUID" -eq 0 ]]; then
@@ -1,6 +1,6 @@
#!/bin/bash
-# Enhanced Puma Viewer Installation Script
+# Enhanced Firestorm Viewer Installation Script
# Features:
# - Creates a timestamped backup of existing installation
diff --git a/indra/newview/viewer_manifest.py b/indra/newview/viewer_manifest.py
index 6b58860f..da0ad2b0 100755
--- a/indra/newview/viewer_manifest.py
+++ b/indra/newview/viewer_manifest.py
@@ -45,7 +45,7 @@ import time
sys.dont_write_bytecode = True # Prevents creating __pycache__ directory
-from pm_viewer_manifest import FSViewerManifest # Manifest extensions for Firestorm
+from pm_viewer_manifest import PMViewerManifest # Manifest extensions for Puma
viewer_dir = os.path.dirname(__file__)
# Add indra/lib/python to our path so we don't have to muck with PYTHONPATH.
@@ -60,7 +60,7 @@ try:
except ImportError:
from llbase import llsd
#
-class ViewerManifest(LLManifest,FSViewerManifest):
+class ViewerManifest(LLManifest,PMViewerManifest):
def is_packaging_viewer(self):
# Some commands, files will only be included
# if we are packaging the viewer on windows.
@@ -130,7 +130,7 @@ class ViewerManifest(LLManifest,FSViewerManifest):
self.path("beamsColors")
# package static_assets folder
- if self.fs_is_opensim():
+ if self.pm_is_opensim():
self.path("static_assets")
self.path("fs_static_assets")
#
@@ -191,7 +191,7 @@ class ViewerManifest(LLManifest,FSViewerManifest):
self.path("*.txt")
self.path("*.xml")
# Include firestorm resources
with self.prefix(src_dst="pm_resources"):
self.path("*.dae") # FIRE-30963 - better physics defaults
@@ -209,7 +209,7 @@ class ViewerManifest(LLManifest,FSViewerManifest):
self.path("*/*.png")
self.path("*.tga")
self.path("*.j2c")
- self.path("*.jpg") # Needed for Firestorm
+ self.path("*.jpg") # Needed for Puma
self.path("*.png")
self.path("textures.xml")
self.path("*/xui/*/*.xml")
@@ -322,9 +322,9 @@ class ViewerManifest(LLManifest,FSViewerManifest):
global CHANNEL_VENDOR_BASE
# a standard map of strings for replacing in the templates
# tag "OS" after CHANNEL_VENDOR_BASE and before any suffix
- channel_base = "Phoenix-" + CHANNEL_VENDOR_BASE
- if self.fs_is_opensim():
- channel_base = channel_base + "OS"
+ channel_base = "Puma-" + CHANNEL_VENDOR_BASE
+# if self.pm_is_opensim():
+# channel_base = channel_base + ""
#
substitution_strings = {
'channel_vendor_base' : '_'.join(channel_base.split()),
@@ -345,8 +345,8 @@ class ViewerManifest(LLManifest,FSViewerManifest):
app_suffix=self.channel_variant()
# tag "OS" after CHANNEL_VENDOR_BASE and before any suffix
- if self.fs_is_opensim():
- app_suffix = "OS" + app_suffix
+# if self.pm_is_opensim():
+# app_suffix = "" + app_suffix
#
# Don't separate name by whitespace. This break a lot of things in the old FS installer logic.
@@ -374,8 +374,8 @@ class ViewerManifest(LLManifest,FSViewerManifest):
if chan in ['alpha', 'nightly','manual', 'profiling']:
chan = 'test'
- if self.fs_is_opensim():
- return "icons/" + chan + "-os"
+ # if self.pm_is_opensim():
+ # return "icons/" + chan + "-os"
#
return "icons/" + chan
@@ -616,7 +616,7 @@ class Windows_x86_64_Manifest(ViewerManifest):
debpkgdir = os.path.join(pkgdir, "lib", "debug")
if self.is_packaging_viewer():
# Find firestorm-bin.exe in the 'configuration' dir, then rename it to the result of final_exe.
self.path(src='%s/puma-bin.exe' % self.args['configuration'], dst=self.final_exe())
# Emit the whole app image as one of the GitHub step outputs. We
# want the whole app -- but NOT the extraneous build products that
@@ -855,7 +855,7 @@ class Windows_x86_64_Manifest(ViewerManifest):
if not self.is_packaging_viewer():
self.package_file = "copied_deps"
- self.fs_copy_windows_manifest( )
+ self.pm_copy_windows_manifest( )
def nsi_file_commands(self, install=True):
# Undo Github-Build stuff - I don't think we need this
@@ -943,17 +943,17 @@ class Windows_x86_64_Manifest(ViewerManifest):
#
def dl_url_from_channel(self):
if self.channel_type() == 'release':
- return 'https://www.firestormviewer.org/choose-your-platform'
+ return 'https://wiki.avataresargentinos.com.ar/descargas'
elif self.channel_type() == 'beta':
- return 'https://www.firestormviewer.org/early-access-beta-downloads'
+ return 'https://wiki.avataresargentinos.com.ar/descargas'
elif self.channel_type() == 'alpha':
- return 'https://www.firestormviewer.org/early-access-alpha-downloads'
+ return 'https://wiki.avataresargentinos.com.ar/descargas'
elif self.channel_type() == 'manual':
- return 'https://www.firestormviewer.org/early-access-manual-downloads'
+ return 'https://wiki.avataresargentinos.com.ar/descargas'
elif self.channel_type() == 'profiling':
- return 'https://www.firestormviewer.org/profiling-downloads'
+ return 'https://wiki.avataresargentinos.com.ar/descargas'
elif self.channel_type() == 'nightly':
- return 'https://www.firestormviewer.org/firestorm-nightly-build-downloads'
+ return 'https://wiki.avataresargentinos.com.ar/descargas'
else:
return ''
@@ -972,19 +972,19 @@ class Windows_x86_64_Manifest(ViewerManifest):
'dl_url':self.dl_url_from_channel()
}
- substitution_strings = self.fs_splice_grid_substitution_strings( substitution_strings ) # Add grid args
+ substitution_strings = self.pm_splice_grid_substitution_strings( substitution_strings ) # Add grid args
# Properly name OS version, also add Phoenix- in front of installer name
#installer_file = self.installer_base_name() + '_Setup.exe'
- installer_file = self.fs_installer_basename() + "_Setup.exe"
+ installer_file = self.pm_installer_basename() + "_Setup.exe"
#
substitution_strings['installer_file'] = installer_file
substitution_strings['is64bit'] = (1 if (self.address_size == 64) else 0)
- substitution_strings['isavx2'] = (1 if (self.fs_is_avx2()) else 0)
- substitution_strings['is_opensim'] = self.fs_is_opensim() # FIRE-30446: Register hop-protocol for OS version only
+ substitution_strings['isavx2'] = (1 if (self.pm_is_avx2()) else 0)
+ substitution_strings['is_opensim'] = self.pm_is_opensim() # FIRE-30446: Register hop-protocol for OS version only
substitution_strings['friendly_app_name'] = self.friendly_app_name() # FIRE-30446: Set FriendlyAppName for protocol registrations
- substitution_strings['icon_suffix'] = ("_os" if (self.fs_is_opensim()) else "") # FIRE-24335: Use different icon for OpenSim version
+ substitution_strings['icon_suffix'] = ("_os" if (self.pm_is_opensim()) else "") # FIRE-24335: Use different icon for OpenSim version
version_vars = """
!define INSTEXE "SLVersionChecker.exe"
@@ -1029,7 +1029,7 @@ class Windows_x86_64_Manifest(ViewerManifest):
tempfile = "puma_setup_tmp.nsi"
- self.fs_sign_win_binaries() # Sign files, step one. Sign compiled binaries
+ self.pm_sign_win_binaries() # Sign files, step one. Sign compiled binaries
# the following replaces strings in the nsi template
# it also does python-style % substitution
@@ -1059,8 +1059,8 @@ class Windows_x86_64_Manifest(ViewerManifest):
self.run_command([possible_path, '/V2', self.dst_path_of(tempfile)])
- self.fs_sign_win_installer(substitution_strings) # Sign files, step two. Sign installer.
- self.fs_save_windows_symbols()
+ self.pm_sign_win_installer(substitution_strings) # Sign files, step two. Sign installer.
+ self.pm_save_windows_symbols()
self.created_path(self.dst_path_of(installer_file))
self.package_file = installer_file
@@ -1814,7 +1814,7 @@ class Darwin_x86_64_Manifest(ViewerManifest):
# Make sure all our package names look similar
#imagename = self.installer_base_name()
- imagename = self.fs_installer_basename()
+ imagename = self.pm_installer_basename()
#
sparsename = imagename + ".sparseimage"
@@ -1850,8 +1850,8 @@ class Darwin_x86_64_Manifest(ViewerManifest):
# - Ambroff 2008-08-20
# Select proper directory based on flavor and build type
dmg_template_prefix = 'puma'
- if self.fs_is_opensim():
- dmg_template_prefix = 'pumaos'
+ if self.pm_is_opensim():
+ dmg_template_prefix = 'puma'
dmg_template = os.path.join(
'installers', 'darwin', '%s-%s-dmg' % (dmg_template_prefix, self.channel_type()))
print ("Trying template directory", dmg_template)
@@ -1970,7 +1970,7 @@ class Darwin_x86_64_Manifest(ViewerManifest):
plain_sign += glob.glob( app_in_dmg + "/Contents/Frameworks/Chromium Embedded Framework.framework/Libraries/*.dylib" )
deep_sign = [
# Firestorm does not ship SLVersionChecker
#resources + "updater/SLVersionChecker",
resources + "SLPlugin.app/Contents/MacOS/SLPlugin",
resources + "SLVoice",
@@ -2032,7 +2032,7 @@ class Darwin_x86_64_Manifest(ViewerManifest):
# get rid of the temp file
self.package_file = finalname
self.remove(sparsename)
- self.fs_save_osx_symbols()
+ self.pm_save_osx_symbols()
class LinuxManifest(ViewerManifest):
@@ -2209,7 +2209,7 @@ class LinuxManifest(ViewerManifest):
#self.path("libexpat.so*")
#self.path("libssl.so*")
#self.path("libGLOD.so")
- #self.fs_path("libminizip.so")
+ #self.pm_path("libminizip.so")
self.path("libuuid.so*")
self.path("libSDL*.so*")
self.path_optional("libdirectfb*.so*")
@@ -2271,12 +2271,12 @@ class LinuxManifest(ViewerManifest):
# a standard map of strings for replacing in the templates
#installer_name = self.installer_base_name()
- installer_name = self.fs_installer_basename()
+ installer_name = self.pm_installer_basename()
- self.fs_save_breakpad_symbols("linux")
- self.fs_delete_linux_symbols() # Delete old syms
+ self.pm_save_breakpad_symbols("linux")
+ self.pm_delete_linux_symbols() # Delete old syms
self.strip_binaries()
- self.fs_save_linux_symbols() # Package symbols, add debug link
+ self.pm_save_linux_symbols() # Package symbols, add debug link
# Fix access permissions
self.run_command(['find', self.get_dst_prefix(),
@@ -2298,7 +2298,7 @@ class LinuxManifest(ViewerManifest):
# --numeric-owner hides the username of the builder for
# security etc.
self.run_command(['tar', '-C', self.get_build_prefix(),
- '--numeric-owner', self.fs_linux_tar_excludes(), '-caf',
+ '--numeric-owner', self.pm_linux_tar_excludes(), '-caf',
tempname + '.tar.xz', installer_name])
else:
print("Skipping %s.tar.xz for non-Release build (%s)" % \
@@ -2396,7 +2396,7 @@ class Linux_i686_Manifest(LinuxManifest):
#self.path("libvivoxoal.so.1") # no - we'll re-use the viewer's own OpenAL lib
self.path("libvivoxsdk.so")
- self.fs_delete_linux_symbols() # Delete old syms
+ self.pm_delete_linux_symbols() # Delete old syms
self.strip_binaries()
@@ -191,7 +191,7 @@ class ViewerManifest(LLManifest,FSViewerManifest):
self.path("*.txt")
self.path("*.xml")
- # Include firestorm resources
+ # Include puma resources
with self.prefix(src_dst="pm_resources"):
self.path("*.dae") # FIRE-30963 - better physics defaults
@@ -616,7 +616,7 @@ class Windows_x86_64_Manifest(ViewerManifest):
debpkgdir = os.path.join(pkgdir, "lib", "debug")
if self.is_packaging_viewer():
- # Find firestorm-bin.exe in the 'configuration' dir, then rename it to the result of final_exe.
+ # Find puma-bin.exe in the 'configuration' dir, then rename it to the result of final_exe.
self.path(src='%s/puma-bin.exe' % self.args['configuration'], dst=self.final_exe())
# Emit the whole app image as one of the GitHub step outputs. We
@@ -1970,7 +1970,7 @@ class Darwin_x86_64_Manifest(ViewerManifest):
plain_sign += glob.glob( app_in_dmg + "/Contents/Frameworks/Chromium Embedded Framework.framework/Libraries/*.dylib" )
deep_sign = [
- # Firestorm does not ship SLVersionChecker
+ # Puma does not ship SLVersionChecker
#resources + "updater/SLVersionChecker",
resources + "SLPlugin.app/Contents/MacOS/SLPlugin",